/**
 * @file libcomprex/archive_api.h Archive API
 * 
 * $Id: archive_api.h,v 1.2 2001/12/31 09:25:20 chipx86 Exp $
 *
 * @Copyright (C) 2001-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBCOMPREX_ARCHIVE_API_H_
#define _LIBCOMPREX_ARCHIVE_API_H_

#include <libcomprex/archive.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Opens an archive for reading or writing.
 *
 * This is similar to cxOpenDir(), but reports information on
 * the archive file itself, as well as all of the files stored
 * inside it.
 *
 * @param path The path to the archive.
 * 
 * @return The archive structure, or NULL if the file couldn't be
 *         opened.
 */
CxArchive *cxOpenArchive(const char *path);

/**
 * Closes an archive.
 *
 * If changes were made to this archive, they will not be saved.
 * To save them, use cxSaveArchive().
 *
 * @param archive The archive structure.
 *
 * @see cxSaveArchive()
 */
void cxCloseArchive(CxArchive *archive);

/**
 * Saves an archive.
 *
 * This will not close the archive. To close the archive, use
 * cxCloseArchive().
 *
 * @param archive  The archive structure.
 * @param filename The destination filename.
 *
 * @return The status of the operation.
 */
CxStatus cxSaveArchive(CxArchive *archive, const char *filename);

#ifdef __cplusplus
}
#endif

#endif /* _LIBCOMPREX_ARCHIVE_API_H_ */

